@@ -22,6 +22,7 @@ def test_disk_formatter(rich_cmp: Any) -> None:
         owner="user",
         status=Disk.Status.READY,
         cluster_name="cluster",
+        org_name=None,
         created_at=isoparse("2017-03-04T12:28:59.759433+00:00"),
         last_usage=isoparse("2017-04-04T12:28:59.759433+00:00"),
         timeout_unused=timedelta(days=1, hours=2, minutes=3, seconds=4),
@@ -39,6 +40,7 @@ def disks_list() -> List[Disk]:
             owner="user",
             status=Disk.Status.PENDING,
             cluster_name="cluster",
+            org_name=None,
             created_at=isoparse("2017-03-04T12:28:59.759433+00:00"),
             last_usage=isoparse("2017-03-08T12:28:59.759433+00:00"),
         ),
@@ -48,6 +50,7 @@ def disks_list() -> List[Disk]:
             owner="user",
             status=Disk.Status.READY,
             cluster_name="cluster",
+            org_name=None,
             created_at=isoparse("2017-04-04T12:28:59.759433+00:00"),
             timeout_unused=timedelta(days=2, hours=3, minutes=4, seconds=5),
         ),
@@ -57,6 +60,7 @@ def disks_list() -> List[Disk]:
             owner="user",
             status=Disk.Status.READY,
             cluster_name="cluster",
+            org_name="test-org",
             created_at=isoparse("2017-05-04T12:28:59.759433+00:00"),
         ),
         Disk(
@@ -65,6 +69,7 @@ def disks_list() -> List[Disk]:
             owner="user",
             status=Disk.Status.BROKEN,
             cluster_name="cluster",
+            org_name=None,
             created_at=isoparse("2017-06-04T12:28:59.759433+00:00"),
         ),
     ]
